==> icons-vue-0.3.0.tgz: package/lib/fog/16.js <==
'use strict';

var __chunk_1 = require('../chunk-d2faeea1.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_Fog16 = {
  name: 'Fog16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = __chunk_1._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M9 30H3a1 1 0 0 1 0-2H9a1 1 0 0 1 0 2zM23 30H13a1 1 0 0 1 0-2H23a1 1 0 0 1 0 2zM27 26H23a1 1 0 0 1 0-2h4a1 1 0 0 1 0 2zM19 26H3a1 1 0 0 1 0-2H19a1 1 0 0 1 0 2zM15 22H3a1 1 0 0 1 0-2H15a1 1 0 0 1 0 2z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M24.8008,9.1416a8.9929,8.9929,0,0,0-17.6006,0A6.5321,6.5321,0,0,0,2,15.5054,6.4518,6.4518,0,0,0,2.5,18H4.76A4.4633,4.4633,0,0,1,4,15.5054a4.517,4.517,0,0,1,4.144-4.481L8.96,10.96l.0991-.812a6.9931,6.9931,0,0,1,13.8838,0l.0986.812.8154.064A4.4947,4.4947,0,0,1,23.5,20H18v2h5.5A6.4944,6.4944,0,0,0,24.8008,9.1416Z"
      }
    }), children]);
  }
};

module.exports = virtual_Fog16;

==> icons-vue-0.6.0.tgz: package/lib/fog/16.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_Fog16 = {
  name: 'Fog16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M24.8008,11.1382a8.9938,8.9938,0,0,0-17.6006,0A6.533,6.533,0,0,0,2,17.5H2V19a1,1,0,0,0,1,1H15a1,1,0,0,0,0-2H4v-.4966H4a4.5176,4.5176,0,0,1,4.144-4.4819l.8155-.064.0991-.812a6.9936,6.9936,0,0,1,13.8838,0l.0986.812.8154.064A4.4962,4.4962,0,0,1,23.5,22H7a1,1,0,0,0,0,2H23.5a6.4963,6.4963,0,0,0,1.3008-12.8618Z"
      }
    }), createElement('rect', {
      attrs: {
        "width": "18",
        "height": "2",
        "x": "2",
        "y": "26",
        "rx": "1"
      }
    }), children]);
  }
};

module.exports = virtual_Fog16;
